@@ -99,7 +99,11 @@ class ga:
     
         self.obj_fct = obj_fct
         self.properties = properties
-                
+        self.properties["nb_bytes"] = np.array(self.properties["nb_bytes"], dtype=int)
+        self.properties["min_val"]  = np.array(self.properties["min_val"], dtype=int)
+        self.properties["max_val"]  = np.array(self.properties["max_val"], dtype=int)
+                    
+                    
         # Paramètres ajustables arbitraires
         self.num_parents_mating = int(sol_per_pop - ratio_new*sol_per_pop)
         self.prop_mut = prop_mut
